divide_votes_matrix: Calculate raw seat matrix

View source: R/biproportional-lower.R

divide_votes_matrixR Documentation

Calculate raw seat matrix

Description

Apply row and column divisors to matrix to get non-rounded seat values.

Usage

divide_votes_matrix(M, col_divisors, row_divisors)

Arguments

M

matrix

col_divisors

divisors to apply to columns

row_divisors

divisors to apply to rows

Value

matrix with the same dimension as M containing non-rounded seat values


proporz documentation built on Nov. 5, 2025, 6:23 p.m.