Skip to contents

Example election data from the 2020 election for the cantonal council of Uri (Landrat) in Switzerland. The data has been extracted from the report "Landratswahlen 2020: Statistische Auswertung".

Usage

uri2020

Format

List containing:

  • votes_matrix the number of votes for each party and district (4 rows, 4 columns)

  • seats_vector with the number of seats per district (length 4)

Examples

uri2020$votes_matrix
#>      Altdorf Bürglen Erstfeld Schattdorf
#> CVP    11471    2822     2309       4794
#> SPGB   11908    1606     1705       2600
#> FDP     9213    1567      946       2961
#> SVP     7756    2945     1573       3498

uri2020$seats_vector
#>    Altdorf    Bürglen   Erstfeld Schattdorf 
#>         15          7          6          9