Apply a list of quorum functions to rows in a votes matrix
Value
Logical vector with length equal to the number of lists/parties (votes_matrix
rows) showing whether they reached the quorum or not.
Note
This is an internal function for quorum calculations in biproporz().