Apply a list of quorum functions to rows in a votes matrix
reached_quorums(votes_matrix, quorum_funcs)Logical vector with length equal to the number of lists/parties (votes_matrix
rows) showing whether they reached the quorum or not.
Votes matrix
A function or a list of quorum functions. For lists, the attribute
"type" must be set which indicates whether ALL or ANY (i.e. at least one) quorums
must be reached.