A named list with district seats (for votes_matrix columns) and party seats
(for rows).
Arguments
votes_matrix
Vote count matrix with votes by party in rows and votes by district
in columns.
district_seats
Vector defining the number of seats per district. Must be the same
length as ncol(votes_matrix). Values are name-matched to votes_matrix columns if both
are named.
If the number of seats per district should be calculated according to the number
of votes, a single number for the total number of seats can be used. weight_votes will be
ignored, as votes_matrix shows the number of voters.
Note that apportioning district seats according to votes is not the general use case.
weight_votes
By default (TRUE) it is assumed that each voter in a district has
as many votes as there are seats in a district. Thus, votes are weighted according to
the number of available district seats with weight_votes_matrix(). Set to FALSE if
votes_matrix shows the number of voters (e.g. because they can only cast
one vote for one party).
method
Apportion method that defines how seats are assigned, see proporz(). Default
is the Sainte-Laguë/Webster method.