weight_votes_matrix: Create weighted votes matrix

View source: R/biproportional-upper.R

weight_votes_matrixR Documentation

Create weighted votes matrix

Description

Weight votes by dividing the votes matrix entries by the number of seats per district. This method is used in upper_apportionment() if weight_votes is TRUE (default).

Usage

weight_votes_matrix(votes_matrix, district_seats)

weight_list_votes(votes_matrix, district_seats)

Arguments

votes_matrix

votes matrix

district_seats

seats per district, vector with same length as ncol(votes_matrix) and names as colnames(votes_matrix)

Value

the weighted votes_matrix which contains the number of voters (not rounded)

Note

weight_list_votes() has been renamed to weight_votes_matrix() in v1.5.2 and is deprecated.

Examples

weight_votes_matrix(uri2020$votes_matrix, uri2020$seats_vector)


proporz documentation built on Nov. 5, 2025, 6:23 p.m.